@@ -1,9 +1,7 @@
 """Archey API module"""
 
-from datetime import datetime
-
 import json
-
+from datetime import datetime
 from typing import List
 
 from archey._version import __version__
@@ -18,6 +16,7 @@ class API:
     At the moment, only JSON has been implemented.
     Feel free to contribute to add other formats as needed.
     """
+
     def __init__(self, entries: List[Entry]):
         self.entries = entries
 
@@ -27,18 +26,13 @@ class API:
         Set `indent` to the number of wanted output indentation tabs (2-space long).
         """
         document = {
-            'data': {
-                entry.name: entry.value for entry in self.entries
+            "data": {entry.name: entry.value for entry in self.entries},
+            "meta": {
+                "version": Utility.version_to_semver_segments(__version__),
+                "date": datetime.now().isoformat(),
+                "count": len(self.entries),
+                "distro": Distributions.get_local().value,
             },
-            'meta': {
-                'version': Utility.version_to_semver_segments(__version__),
-                'date': datetime.now().isoformat(),
-                'count': len(self.entries),
-                'distro': Distributions.get_local().value,
-            }
         }
 
-        return json.dumps(
-            document,
-            indent=((indent * 2) or None)
-        )
+        return json.dumps(document, indent=((indent * 2) or None))
