@@ -7,7 +7,6 @@ Interface to `os-release` (through `distro` module).
 import os
 import platform
 import sys
-
 from contextlib import suppress
 from enum import Enum
 from functools import lru_cache
@@ -22,37 +21,39 @@ class Distributions(Enum):
     Values contain their respective `distro` identifier.
     See <https://distro.readthedocs.io/en/latest/#distro.id>.
     """
-    ALPINE = 'alpine'
-    ANDROID = 'android'
-    ARCH = 'arch'
-    BUILDROOT = 'buildroot'
-    BUNSENLABS = 'bunsenlabs'
-    CENTOS = 'centos'
-    CRUNCHBANG = 'crunchbang'
-    DARWIN = 'darwin'
-    DEBIAN = 'debian'
-    DEVUAN = 'devuan'
-    ELEMENTARY = 'elementary'
-    FEDORA = 'fedora'
-    FREEBSD = 'freebsd'
-    GENTOO = 'gentoo'
-    KALI = 'kali'
-    MANJARO = 'manjaro'
-    NETBSD = 'netbsd'
-    NIXOS = 'nixos'
-    LINUX = 'linux'
-    LINUXMINT = 'linuxmint'
-    OPENBSD = 'openbsd'
-    OPENSUSE = 'opensuse'
-    POP = 'pop'
-    PARABOLA = 'parabola'
-    RASPBIAN = 'raspbian'
-    ROCKY = 'rocky'
-    RHEL = 'rhel'
-    SLACKWARE = 'slackware'
-    UBUNTU = 'ubuntu'
-    WINDOWS = 'windows'
 
+    ALPINE = "alpine"
+    ANDROID = "android"
+    ARCH = "arch"
+    BUILDROOT = "buildroot"
+    BUNSENLABS = "bunsenlabs"
+    CENTOS = "centos"
+    CRUNCHBANG = "crunchbang"
+    DARWIN = "darwin"
+    DEBIAN = "debian"
+    DEVUAN = "devuan"
+    ELEMENTARY = "elementary"
+    FEDORA = "fedora"
+    FREEBSD = "freebsd"
+    GENTOO = "gentoo"
+    GUIX = "guix"
+    KALI = "kali"
+    MANJARO = "manjaro"
+    NETBSD = "netbsd"
+    NIXOS = "nixos"
+    LINUX = "linux"
+    LINUXMINT = "linuxmint"
+    OPENBSD = "openbsd"
+    OPENSUSE = "opensuse"
+    POP = "pop"
+    PARABOLA = "parabola"
+    RASPBIAN = "raspbian"
+    ROCKY = "rocky"
+    RHEL = "rhel"
+    SIDUCTION = "siduction"
+    SLACKWARE = "slackware"
+    UBUNTU = "ubuntu"
+    WINDOWS = "windows"
 
     @staticmethod
     def get_identifiers() -> List[str]:
@@ -61,14 +62,14 @@ class Distributions(Enum):
 
     @staticmethod
     @lru_cache(maxsize=None)  # Python < 3.9, `functools.cache` is not yet available.
-    def get_local() -> 'Distributions':
+    def get_local() -> "Distributions":
         """Entry point of Archey distribution detection logic"""
         distribution = Distributions._vendor_detection()
 
         # In case nothing got detected the "regular" way...
         if not distribution:
             # Are we running on Darwin (somehow not previously detected by `distro`) ?
-            if platform.system() == 'Darwin':
+            if platform.system() == "Darwin":
                 return Distributions.DARWIN
 
             # Android systems are currently not being handled by `distro`.
@@ -77,8 +78,9 @@ class Distributions(Enum):
             #  See <https://github.com/python/cpython/search?l=Python&q=getandroidapilevel>
             # As a fallback, we mimic Neofetch behavior, by relying on the file-system.
             #  See <https://github.com/nir0s/distro/issues/253>
-            if hasattr(sys, 'getandroidapilevel') \
-                or (os.path.isdir('/system/app') and os.path.isdir('/system/priv-app')):
+            if hasattr(sys, "getandroidapilevel") or (
+                os.path.isdir("/system/app") and os.path.isdir("/system/priv-app")
+            ):
                 return Distributions.ANDROID
 
             # If nothing of the above matched, fall-back on the Linux logo.
@@ -91,29 +93,25 @@ class Distributions(Enum):
             # Below conditions are here to work-around this issue.
             # First condition : CrunchBang-Linux and CrunchBang-Monara.
             # Second condition : CrunchBang++ (CBPP).
-            if os.path.isfile('/etc/lsb-release-crunchbang') \
-                or os.path.isfile('/usr/bin/cbpp-exit'):
+            if os.path.isfile("/etc/lsb-release-crunchbang") or os.path.isfile(
+                "/usr/bin/cbpp-exit"
+            ):
                 return Distributions.CRUNCHBANG
 
         elif distribution == Distributions.UBUNTU:
             # Older Pop!_OS releases (< 20.*) didn't ship their own `ID` (from `os-release`).
             # Thus, they are detected as "regular" Ubuntu distributions.
             # We may here rely on their `NAME` (from `os-release`), which is sufficient.
-            if Distributions.get_distro_name(pretty=False) == 'Pop!_OS':
+            if Distributions.get_distro_name(pretty=False) == "Pop!_OS":
                 return Distributions.POP
 
         return distribution
 
     @staticmethod
-    def _vendor_detection() -> Optional['Distributions']:
+    def _vendor_detection() -> Optional["Distributions"]:
         """Main distribution detection logic, relying on `distro`, handling _common_ cases"""
         # Are we running on Windows ?
-        if platform.system() == 'Windows':
-            return Distributions.WINDOWS
-
-        # Is it a Windows Sub-system Linux (WSL) distribution ?
-        # If so, kernel release identifier should keep a trace of it.
-        if 'microsoft' in platform.release().lower():
+        if platform.system() == "Windows":
             return Distributions.WINDOWS
 
         # Is `ID` (from `os-release`) well-known and supported ?
@@ -122,7 +120,7 @@ class Distributions(Enum):
 
         # Is any of `ID_LIKE` (from `os-release`) well-known and supported ?
         # See <https://www.freedesktop.org/software/systemd/man/os-release.html#ID_LIKE=>.
-        for id_like in distro.like().split(' '):
+        for id_like in distro.like().split(" "):
             with suppress(ValueError):
                 return Distributions(id_like)
 
@@ -140,4 +138,4 @@ class Distributions(Enum):
         Simple wrapper to `distro` to return the distribution preferred ANSI color.
         See <https://www.freedesktop.org/software/systemd/man/os-release.html#ANSI_COLOR=>.
         """
-        return distro.os_release_attr('ansi_color') or None
+        return distro.os_release_attr("ansi_color") or None
