@@ -6,18 +6,17 @@ import platform
 from archey.entry import Entry
 from archey.processes import Processes
 
-
 DE_DICT = {
-    'cinnamon': 'Cinnamon',
-    'dde-dock': 'Deepin',
-    'fur-box-session': 'Fur Box',
-    'gnome-session': 'GNOME',
-    'gnome-shell': 'GNOME',
-    'ksmserver': 'KDE',
-    'lxqt-session': 'LXQt',
-    'lxsession': 'LXDE',
-    'mate-session': 'MATE',
-    'xfce4-session': 'Xfce'
+    "cinnamon": "Cinnamon",
+    "dde-dock": "Deepin",
+    "fur-box-session": "Fur Box",
+    "gnome-session": "GNOME",
+    "gnome-shell": "GNOME",
+    "ksmserver": "KDE",
+    "lxqt-session": "LXQt",
+    "lxsession": "LXDE",
+    "mate-session": "MATE",
+    "xfce4-session": "Xfce",
 }
 
 
@@ -26,15 +25,16 @@ class DesktopEnvironment(Entry):
     Just iterate over running processes to find a known-entry.
     If not, rely on the `XDG_CURRENT_DESKTOP` environment variable.
     """
-    _PRETTY_NAME = 'Desktop Environment'
+
+    _PRETTY_NAME = "Desktop Environment"
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
         # macOS' desktop environment is called "Aqua",
         #   and could not be detected from processes list.
-        if platform.system() == 'Darwin':
-            self.value = 'Aqua'
+        if platform.system() == "Darwin":
+            self.value = "Aqua"
             return
 
         processes = Processes().list
@@ -44,4 +44,4 @@ class DesktopEnvironment(Entry):
                 break
         else:
             # Let's rely on an environment variable if the loop above didn't `break`.
-            self.value = os.getenv('XDG_CURRENT_DESKTOP')
+            self.value = os.getenv("XDG_CURRENT_DESKTOP")
