@@ -4,9 +4,8 @@ import json
 import os
 import platform
 import re
-
 from glob import iglob
-from subprocess import CalledProcessError, DEVNULL, PIPE, check_output, run
+from subprocess import DEVNULL, PIPE, CalledProcessError, check_output, run
 from typing import List, Optional
 
 from archey.entry import Entry
@@ -19,6 +18,7 @@ class Temperature(Entry):
       or `sysctl` output for BSD and derivatives systems.
     On Raspberry devices, retrieves temperature from the `vcgencmd` binary.
     """
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -31,10 +31,10 @@ class Temperature(Entry):
 
         # On error (list still empty)...
         if not self._temps:
-            if platform.system() == 'Linux':
+            if platform.system() == "Linux":
                 # ... checks for system thermal zones files on GNU/Linux.
                 self._poll_thermal_zones()
-            elif platform.system() == 'Darwin':
+            elif platform.system() == "Darwin":
                 self._run_istats_or_osxcputemp()
             else:
                 # ... or tries `sysctl` calls (available on BSD and derivatives).
@@ -48,8 +48,8 @@ class Temperature(Entry):
             return
 
         # Let's DRY some constants once.
-        use_fahrenheit = self.options.get('use_fahrenheit')
-        char_before_unit = self.options.get('char_before_unit', ' ')
+        use_fahrenheit = self.options.get("use_fahrenheit")
+        char_before_unit = self.options.get("char_before_unit", " ")
 
         # Conversion to Fahrenheit if needed.
         if use_fahrenheit:
@@ -57,34 +57,29 @@ class Temperature(Entry):
 
         # Final average and maximum computations.
         self.value = {
-            'temperature': float(round(sum(self._temps) / len(self._temps), 1)),
-            'max_temperature': float(round(max(self._temps), 1)),
-            'char_before_unit': char_before_unit,
-            'unit': ('F' if use_fahrenheit else 'C')
+            "temperature": float(round(sum(self._temps) / len(self._temps), 1)),
+            "max_temperature": float(round(max(self._temps), 1)),
+            "char_before_unit": char_before_unit,
+            "unit": ("F" if use_fahrenheit else "C"),
         }
 
-
     def _run_sensors(
         self,
         whitelisted_chips: Optional[List[str]] = None,
         excluded_subfeatures: Optional[List[str]] = None,
     ):
-
         def _get_sensors_output(whitelisted_chip: Optional[str]) -> Optional[str]:
-            sensors_args = ['sensors', '-A', '-j']
+            sensors_args = ["sensors", "-A", "-j"]
             if whitelisted_chip is not None:
                 sensors_args.append(whitelisted_chip)
 
-            # Uses the `sensors` program (from lm-sensors) to interrogate thermal chip-sets.
+            # Uses the `sensors` program (from lm-sensors) to query thermal chipsets.
+            error_message = None
             try:
                 sensors_output = run(
-                    sensors_args,
-                    universal_newlines=True,
-                    stdout=PIPE, stderr=PIPE,
-                    check=True
+                    sensors_args, universal_newlines=True, stdout=PIPE, stderr=PIPE, check=True
                 )
             except FileNotFoundError:
-                error_message = None
                 return None
             except CalledProcessError as called_process_error:
                 error_message = called_process_error.stderr
@@ -95,7 +90,7 @@ class Temperature(Entry):
                 # Log any `sensors` error messages at warning level.
                 if error_message:
                     for line in error_message.splitlines():
-                        self._logger.warning('[lm-sensors]: %s', line)
+                        self._logger.warning("[lm-sensors]: %s", line)
 
             return sensors_output.stdout
 
@@ -116,7 +111,7 @@ class Temperature(Entry):
                 sensors_data = json.loads(sensors_output)
             except json.JSONDecodeError as json_decode_error:
                 self._logger.warning(
-                    'Couldn\'t decode JSON from sensors output : %s', json_decode_error
+                    "Couldn't decode JSON from sensors output : %s", json_decode_error
                 )
                 continue
 
@@ -138,11 +133,11 @@ class Temperature(Entry):
                             #  we may stop the current sub-feature iteration now.
                             break
 
-    def _poll_thermal_zones(self):
+    def _poll_thermal_zones(self) -> None:
         # We just check for values within files present in the path below.
-        for thermal_file in iglob(r'/sys/class/thermal/thermal_zone*/temp'):
+        for thermal_file in iglob(r"/sys/class/thermal/thermal_zone*/temp"):
             try:
-                with open(thermal_file, encoding='ASCII') as file:
+                with open(thermal_file, encoding="ASCII") as file:
                     temp = float(file.read())
             except OSError:
                 continue
@@ -150,7 +145,7 @@ class Temperature(Entry):
             if temp != 0.0:
                 self._temps.append(temp / 1000)
 
-    def _run_istats_or_osxcputemp(self):
+    def _run_istats_or_osxcputemp(self) -> None:
         """
         For Darwin systems, let's rely on `iStats` or `OSX CPU Temp` third-party programs.
         System's `powermetrics` program is **very** slow to run
@@ -159,8 +154,7 @@ class Temperature(Entry):
         # Run iStats binary (<https://github.com/Chris911/iStats>).
         try:
             istats_output = check_output(
-                ['istats', 'cpu', 'temperature', '--value-only'],
-                universal_newlines=True
+                ["istats", "cpu", "temperature", "--value-only"], universal_newlines=True
             )
         except OSError:
             pass
@@ -170,67 +164,63 @@ class Temperature(Entry):
 
         # Run OSX CPU Temp binary (<https://github.com/lavoiesl/osx-cpu-temp>).
         try:
-            osxcputemp_output = check_output('osx-cpu-temp', universal_newlines=True)
+            osxcputemp_output = check_output("osx-cpu-temp", universal_newlines=True)
         except OSError:
             pass
         else:
             # Parse output across <= 1.1.0 versions and above.
-            temp = float(re.search(r'\d+\.\d', osxcputemp_output).group(0))
+            temp_match = re.search(r"\d+\.\d", osxcputemp_output)
+            if temp_match is None:
+                return
+            temp = float(temp_match.group(0))
             if temp != 0.0:  # (Apple) System Management Control read _may_ fail.
                 self._temps.append(temp)
 
-    def _run_sysctl_dev_cpu(self):
+    def _run_sysctl_dev_cpu(self) -> None:
         # Tries to get temperatures from each CPU core sensor.
         try:
             sysctl_output = check_output(
-                ['sysctl', '-n'] + \
-                    [f'dev.cpu.{i}.temperature' for i in range(os.cpu_count())],
-                stderr=PIPE, universal_newlines=True
+                ["sysctl", "-n"] + [f"dev.cpu.{i}.temperature" for i in range(os.cpu_count() or 1)],
+                stderr=PIPE,
+                universal_newlines=True,
             )
         except FileNotFoundError:
             # `sysctl` does not seem to be available on this system.
             return
         except CalledProcessError as error_message:
             self._logger.warning(
-                '[sysctl]: Couldn\'t fetch temperature from CPU sensors (%s). '
-                'Please be sure to load the corresponding kernel driver beforehand '
-                '(`kldload coretemp` for Intel or `kldload amdtemp` for AMD`).',
-                (error_message.stderr or 'unknown error').rstrip()
+                "[sysctl]: Couldn't fetch temperature from CPU sensors (%s). "
+                "Please be sure to load the corresponding kernel driver beforehand "
+                "(`kldload coretemp` for Intel or `kldload amdtemp` for AMD`).",
+                (error_message.stderr or "unknown error").rstrip(),
             )
             return
 
-        for temp in sysctl_output.splitlines():
+        for temp_output in sysctl_output.splitlines():
             # Strip any temperature unit from output (some drivers may add it).
-            temp = float(temp.rstrip('C'))
+            temp = float(temp_output.rstrip("C"))
             if temp != 0.0:
                 self._temps.append(temp)
 
-    def _run_vcgencmd(self):
+    def _run_vcgencmd(self) -> None:
         # Let's try to retrieve a value from the Broadcom chip on Raspberry.
         try:
             vcgencmd_output = check_output(
-                ['/opt/vc/bin/vcgencmd', 'measure_temp'],
-                stderr=DEVNULL, universal_newlines=True
+                ["/opt/vc/bin/vcgencmd", "measure_temp"], stderr=DEVNULL, universal_newlines=True
             )
         except (FileNotFoundError, CalledProcessError):
             return
 
-        self._temps.append(
-            float(
-                re.search(
-                    r'\d+\.\d+',
-                    vcgencmd_output
-                ).group(0)
-            )
-        )
+        temp_match = re.search(r"\d+\.\d+", vcgencmd_output)
+        if temp_match is not None:
+            self._temps.append(float(temp_match.group(0)))
 
     @staticmethod
     def _convert_to_fahrenheit(temp: float) -> float:
         """Simple Celsius to Fahrenheit conversion method"""
         return temp * (9 / 5) + 32
 
-
-    def output(self, output):
+    def output(self, output) -> None:
         """Adds the entry to `output` after pretty-formatting with units."""
         if not self.value:
             # Fall back on the default behavior if no temperatures were detected.
@@ -238,8 +228,8 @@ class Temperature(Entry):
             return
 
         # DRY some constants
-        char_before_unit = self.value['char_before_unit']
-        unit = self.value['unit']
+        char_before_unit = self.value["char_before_unit"]
+        unit = self.value["unit"]
 
         entry_text = f"{self.value['temperature']}{char_before_unit}{unit}"
         # When there are multiple input sources, show the hottest value.
