@@ -2,7 +2,6 @@
 
 from archey.colors import Colors
 
-
 COLORS = [Colors.RED_BRIGHT, Colors.WHITE_BRIGHT, Colors.RED_NORMAL]
 
 LOGO = [
@@ -21,5 +20,5 @@ LOGO = [
     """{c[0]} {c[1]}MMM    MMMMMMMMMMMMMMyyddMMM+{c[0]}            """,
     """{c[0]}  {c[1]}MMMM   MMMMMMMMMMMMMNdyNMMh\\`     hyhMMM{c[0]}""",
     """{c[0]}   {c[1]}MMMMMMMMMMMMMMMMyoNNNMMM+.   MMMMMMMM{c[0]}  """,
-    """{c[0]}    {c[1]}MMNMMMNNMMMMMNM+ mhsMNyyyyMNMMMMsMM{c[0]}   """
+    """{c[0]}    {c[1]}MMNMMMNNMMMMMNM+ mhsMNyyyyMNMMMMsMM{c[0]}   """,
 ]
