@@ -2,7 +2,6 @@
 
 from archey.colors import Colors
 
-
 COLORS = [Colors.BLUE_NORMAL, Colors.BLUE_BRIGHT, Colors.CLEAR]
 
 # pylint: disable=line-too-long
@@ -27,5 +26,5 @@ LOGO = [
     """{c[0]}       {c[1]}::::::::::::::::::::::::::::::::{c[0]}      """,
     """{c[0]}         {c[1]}::::::::::::::::::::::::::::{c[0]}        """,
     """{c[0]}            {c[1]}::::::::::::::::::::::{c[0]}           """,
-    """{c[0]}                 {c[1]}::::::::::::{c[0]}                """
+    """{c[0]}                 {c[1]}::::::::::::{c[0]}                """,
 ]
