@@ -1,20 +1,17 @@
 """Simple class (acting as a singleton) to handle processes listing"""
 
 import logging
-
-from subprocess import CalledProcessError, PIPE, check_output
+from subprocess import PIPE, CalledProcessError, check_output
 
 from archey.singleton import Singleton
 
 
 class Processes(metaclass=Singleton):
     """At startup, instantiate this class to populate a list of running processes"""
+
     def __init__(self):
         try:
-            ps_output = check_output(
-                ['ps', '-eo', 'comm'],
-                stderr=PIPE, universal_newlines=True
-            )
+            ps_output = check_output(["ps", "-eo", "comm"], stderr=PIPE, universal_newlines=True)
         except FileNotFoundError:
             self._processes = []
             logging.warning("`procps` (or `procps-ng`) couldn't be found on your system.")
